/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


package sync4j.framework.core;


/**
 * Corresponds to &lt;Alert&gt; element in SyncML represent DTD
 *
 * @author Stefano Fornari @ Funambol
 * @see    AlertCode
 *
 * @version $Id: Alert.java,v 1.1 2005/05/16 17:32:54 nichele Exp $
 */
public final class Alert
extends ItemizedCommand 
implements java.io.Serializable {
    
    // --------------------------------------------------------------- Constants
    public static String COMMAND_NAME = "Alert";
    
    // ------------------------------------------------------------ Private data
    private int data;
    
    // ------------------------------------------------------------ Constructors
    
    /** For serialization purposes */
    protected Alert() {}
    
    /**
     * Creates a new Alert object with the given command identifier, 
     * noResponse, authentication credential, alert code and array of item
     *
     * @param cmdID command identifier - NOT NULL
     * @param noResp is true if no response is required
     * @param cred the authentication credential
     * @param data the code of Alert
     * @param items the array of item - NOT NULL
     *
     */
    public Alert(final CmdID cmdID,
                 final boolean noResp,
                 final Cred cred,
                 final int data,
                 final Item[] items) {
        super(cmdID, items);
        
        this.noResp  = (noResp) ? new Boolean(noResp) : null;
        setCred(cred);        
        
        this.data = data;
    }

    // ---------------------------------------------------------- Public methods

    /**
     * Gets the alert code
     *
     * @return the alert code
     */ 
    public int getData() {
        return data;
    }
    
    /**
     * Sets the alert code
     *
     * @param data the alert code
     */ 
    public void setData(int data) {
        this.data = data;
    }
    
    /**
     * Gets the command name property
     *
     * @return the command name property
     */    
    public String getName() {
        return Alert.COMMAND_NAME;
    }
}