/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package sync4j.framework.core.bootstrap;

import java.io.ByteArrayOutputStream;
import java.util.ArrayList;
import java.util.List;

import org.jibx.runtime.BindingDirectory;
import org.jibx.runtime.IBindingFactory;
import org.jibx.runtime.IMarshallingContext;
import org.jibx.runtime.JiBXException;


/**
 * Corresponds to the &lt;wap-provisioningdoc&gt; tag in a Wap provisioning doc.
 *
 * @author Stefano Nichele
 *
 * @version $Id: WapProvisioningDoc.java,v 1.1 2005/05/16 17:32:54 nichele Exp $
 *
 */
public final class WapProvisioningDoc {

    // -------------------------------------------------------------- Properties
    private ArrayList characteristics = null;

    private String version = null;

    // ------------------------------------------------------------ Constructors

    /**
     * Creates a new WapProvisioningDoc
     */
    public WapProvisioningDoc() {
        characteristics = new ArrayList();
    }


    /**
     * Creates a new WapProvisioningDoc with the given versione
     * @param version the version of this WapProvisioningDoc
     */
    public WapProvisioningDoc(String version) {
        this.version = version;
        characteristics = new ArrayList();
    }


    /**
      * Gets the version of this WapProvisioningDoc
      * @return the version of this WapProvisioningDoc
      */
     public String getVersion() {
         return version;
     }

     /**
      * Sets the version of this WapProvisioningDoc
      * @param name the version to set
      */
     public void setVersion(String version) {
         this.version = version;
     }

    /**
     * Adds new <code>Characteristic</code> to this WapProvisioningDoc
     *
     * @param characteristicToAdd the characteristic to add
     */
    public void addCharacteristic(Characteristic characteristicToAdd) {
        characteristics.add(characteristicToAdd);
    }

    /**
     * Adds a list of<code>Characteristic</code> to this WapProvisioningDoc
     *
     * @param characteristicToAdd the characteristic to add
     */
    public void addCharacteristicList(List characteristicsToAdd) {
            characteristics.addAll(characteristicsToAdd);
    }

    /**
     * Returns a xml representation of this WapProvisioningDoc
     * @return String
     */
    public String toXml() throws JiBXException {
        ByteArrayOutputStream bout = new ByteArrayOutputStream();

        IBindingFactory f = BindingDirectory.getFactory(WapProvisioningDoc.class);
        IMarshallingContext c = f.createMarshallingContext();
        c.setIndent(0);
        c.marshalDocument(this, "UTF-8", null, bout);

        String inputXml = new String(bout.toByteArray());

        return inputXml;

    }

}