/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package sync4j.framework.server.dm;

import sync4j.framework.engine.dm.ManagementProcessor;
import sync4j.framework.engine.dm.DeviceDMState;
import sync4j.framework.core.dm.ddf.DevInfo;


/**
 * This interface defines the structure of a Processor Selector. A Processor 
 * selector is the component that implements the logic to select the specific
 * processor manager that should handle the management session.
 *
 * @author  Stefano Fornari @ Funambol
 *
 * @version $Id: ProcessorSelector.java,v 1.1 2005/05/16 17:32:56 nichele Exp $
 */
public interface ProcessorSelector {
    
    /**
     * Returns the processor manager that will handle the management session. <br>
     * The selection can be done accordingly to any logic and relevan data.
     * However, at least the device info obtained by the client are given.
     *
     * @param dms the device management state
     * @param devInfo the ./DevInfo standardized object provided by the client
     *
     * @return the processor manager that will handle the management session
     */
    public ManagementProcessor getProcessor(DeviceDMState dms, DevInfo devInfo);
}