/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package sync4j.framework.tools.beans;

/**
 * This interface models beans that supports or requires lazy initialization.
 * When a bean is created, first of all the empty constructor is created and
 * the the bean properties are set. If a bean requires that its properties have 
 * a proper value when initialization is performed it should implement 
 * <i>LazyInitBean</i>, so that the caller has an opportunity to separately 
 * initialize the bean after its creation, but before using it.<br>
 * The described mechanism is used in BeanFactory when an instance of the bean
 * is created. If the bean implements <i>LazyInitBean</i> after creating the bean
 * the method init() is called.
 * 
 * @see BeanFactory
 *
 * @author  Stefano Fornari @ Funambol
 * @version $Id: LazyInitBean.java,v 1.1 2005/05/16 17:32:56 nichele Exp $
 */
public interface LazyInitBean {
    public void init() throws BeanInitializationException;
}